@@ -67,24 +67,48 @@ ClutterActor* singinggame_add_cursor(ClutterColor* color, JammoSequencer* sequen
 	ClutterActor* texture_image;
 	ClutterActor* cursor;
 
-	//Try to use song's own cursor.png
-	gchar* filepath1 = g_strdup_printf("%s/cursor.png",(chum_get_current_song())->fullpath);
+
+	//Priorities:
+	//1: cursor relating this language and this song
+	//2: cursor relating this song
+	//3: ad-hoc box
+	gchar* filepath1;
+	filepath1 = g_strdup_printf("%s/cursor%s.png",(chum_get_current_song())->fullpath, chum_get_selected_language() );
+
 	int fd = open(filepath1,O_RDONLY);
-	if (fd == -1) //File not found
+	if (fd == -1) //File not found -> no cursor relating to this language
 		{
-		gchar* message = g_strdup_printf("file '%s' not found",filepath1);
-		cem_add_to_log(message,J_LOG_WARN);
+		gchar* message = g_strdup_printf("no language-specific cursor '%s', checking if any cursor",filepath1);
+		cem_add_to_log(message,J_LOG_DEBUG);
 		g_free(message);
+
+		g_free(filepath1);
+		filepath1=NULL;
+		filepath1 = g_strdup_printf("%s/cursor.png",(chum_get_current_song())->fullpath);
+		fd = open(filepath1,O_RDONLY);
+		if (fd == -1) //File not found -> no any cursor for this song
+			{
+			message = g_strdup_printf("no any cursor '%s', using empty box",filepath1);
+			cem_add_to_log(message,J_LOG_DEBUG);
+			g_free(message);
+
+			g_free(filepath1);
+			filepath1=NULL;
+			}
+		}
+
+	if (filepath1) {
+		texture_image = tangle_texture_new(filepath1);
+		g_free(filepath1);
+	}
+
+	else {
 		ClutterColor transparency = { 0, 0, 0, 0 };
 		texture_image = clutter_rectangle_new_with_color(&transparency);
 		clutter_actor_set_size(texture_image, 60.0,60.0);
-		}
-	else
-		{
-		texture_image = tangle_texture_new(filepath1);
-		}
-	g_free(filepath1);
-	
+	}
+
+
 	gfloat width,height;
 	clutter_actor_get_size(texture_image, &width, &height);
 	
@@ -400,11 +424,18 @@ void singinggame_start_songselection(){
 		audio_filename = g_strdup_printf("%s/vocal%s.ogg",song->fullpath,selected_language);
 		//printf("filename for vocal: '%s'\n",audio_filename);
 
+
+		int fd_intro; //Checking if there are introXX.spx -> then do not dim icon.
+		gchar* filepath1;
+		filepath1 =  g_strdup_printf("%s/intro%s.spx", song->fullpath, chum_get_selected_language());
+		fd_intro = open(filepath1,O_RDONLY);
+		g_free(filepath1);
+
 		ClutterActor* texture;
 		g_object_get(song->songbutton,"normal-background-actor", &texture, NULL);
 
 		int fd = open(audio_filename,O_RDONLY);
-		if (fd == -1  && chum_get_duetto() ) //File not found => no vocal_track for this language
+		if (fd == -1  && chum_get_duetto() && fd_intro == -1) //File not found => no vocal_track for this language
 			{
 			//printf(" Dim this\n");
 			clutter_actor_set_opacity(texture ,64); //0=transparency, 255=opaque
@@ -533,6 +564,10 @@ gboolean singinggame_language_clicked (TangleActor* actor, gpointer data) {
 	clutter_actor_hide(jammo_get_actor_by_id("language-selection-view"));
 	clutter_actor_show(view);
 
+	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), ""); //If it takes too long to load
+	ClutterActor* hourglass = jammo_get_actor_by_id("wait");
+	clutter_actor_show(hourglass);
+	singinggame_force_reinit_songs();
 	return TRUE;
 }
 
