@@ -15,7 +15,7 @@
 #include "../../meam/jammo-sample.h"
 #include "chum.h"
 
-#include "../pen_gesture/login_screen.h"
+#include "pen_gesture/login_screen.h"
 
 static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 	ClutterActor* actor;
