@@ -15,18 +15,7 @@ This file contains the functionality of the avatar editor.
 */
 void start_avatar_editor();
 
-/*
-* Sets avatar picture and other widgets 
-*
-* parameters:
-* -avatar    Avatar struct that contains avatar parts
-* -avatarImage   Container where to put avatar parts
-* -instrumentBackground   Background for favourite instrument image
-* -widget     Other widgets to show (i.e. "avatar-widgets" in avatar_editor.json or 
-*									 "user-profile-widgets" in profile_viewer.json
-*
-*/
-void set_avatar(Avatar*, ClutterActor*, ClutterActor*, char*);
+void set_avatar(Avatar*, ClutterActor*);
 
 
 gboolean sendJammoUserProfile(gchar* user_profile);
@@ -35,5 +24,7 @@ gboolean avatar_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
 
 gboolean avatar_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 
+void show_roster(gboolean editor);
+void end_roster(gboolean editor);
 
 #endif
