@@ -20,7 +20,6 @@ static gboolean renaming_loop = FALSE;
 
 static void rename_loop(ClutterActor* loopName, int type);
 static void hide_song_label();
-static gboolean add_single_button(ClutterActor* button, ClutterContainer* list, char* path, int width,int height, GCallback function);
 
 //Long click:  rename the item
 void song_on_held_function(TangleButton* button, gpointer user_data) {
@@ -90,10 +89,9 @@ static void rename_loop(ClutterActor *loopName, int type){
 	gchar * newpath = NULL;
 	int i = 0, j = 0, type_length = 0, path_length = 0, userid_length = 10;
 	int length = strlen(filename);
-	char temp[length];
 	char oldpath[length];
 
-	strcpy(temp, filename);
+	gchar* temp = g_strdup_printf("%s", filename);
 
 	if(type == 0){ //projects
 		path_length = strlen(configure_get_projects_directory());
@@ -108,6 +106,7 @@ static void rename_loop(ClutterActor *loopName, int type){
 		j++;
 	}
 	oldpath[j] = 0;
+	g_free(temp);
 
 	gchar * path = NULL;
 
@@ -323,7 +322,14 @@ static gboolean clear_community_temp_directory(){
  * -listToClear is the container to be cleared
 **/
 void community_utilities_clear_container_recursively(ClutterContainer *listToClear){
-	
+
+	if (CLUTTER_IS_ACTOR(listToClear)){
+		//Revert back it's scrolling parameters
+		ClutterAction* scroll_action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(listToClear),TANGLE_TYPE_SCROLL_ACTION);
+		if (scroll_action) {
+			tangle_scroll_action_set_thresholds(TANGLE_SCROLL_ACTION(scroll_action), 30.0,30.0);
+		}
+	}
 	int i = 0;
 	GList *listItems;
 	
@@ -361,22 +367,36 @@ void community_utilities_clear_container_recursively(ClutterContainer *listToCle
  * -width is the width of the button
  * -height is the height of the button
 **/
-gboolean community_utilities_make_buttons_from_directory(const char* path, ClutterContainer *list, GCallback function, int width, int height){
+gboolean community_utilities_make_buttons_from_directory(const char* path, ClutterContainer* scrolling_container, GCallback function, int width, int height){
 	ClutterActor *button = 0;
-	char tempPath[150];
 	char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN];
 	int numberOfImages;
 	
 	numberOfImages = community_utilities_open_and_arrange_dir(path, ".png", result);
 	
 	for(int i = 0; i < numberOfImages; i++){
-		strcpy(tempPath, path);
-		strcat(tempPath, result[i]);
-		add_single_button(button, list, tempPath, width, height, function);
-	
+		gchar* image_path = g_strdup_printf("%s%s", path,result[i]);
+		community_utilities_add_single_button(button, scrolling_container, image_path, width, height, function);
+		g_free(image_path);
 	}
-	
-  	return TRUE;
+
+	if (numberOfImages*width <= 800){
+		//Do not scroll it, they fit.
+		ClutterAction* scroll_action = tangle_actor_get_action_by_type(CLUTTER_ACTOR(scrolling_container),TANGLE_TYPE_SCROLL_ACTION);
+		tangle_scroll_action_set_thresholds(TANGLE_SCROLL_ACTION(scroll_action), 30000.0,3000.0);
+
+		//Adjust position
+		g_object_set(G_OBJECT(scroll_action), "offset-x", 0.0, NULL);
+
+		//If scroller is very this moment scrolling, this is needed to stop it
+		tangle_object_animate(G_OBJECT(scroll_action),  CLUTTER_EASE_IN_OUT_QUAD, 50, "offset-x", 0.0, NULL);
+
+	clutter_actor_set_width(CLUTTER_ACTOR(scrolling_container),numberOfImages*width);
+	}
+	else
+		clutter_actor_set_width(CLUTTER_ACTOR(scrolling_container),800.0);
+
+	return TRUE;
 }	
 
 /**
@@ -390,7 +410,8 @@ gboolean community_utilities_make_buttons_from_directory(const char* path, Clutt
  * -height is the height of the button
  * -funtion is a pointer to a function which handles button press events
 **/
-static gboolean add_single_button(ClutterActor* button, ClutterContainer* list, char* path, int width, int height, GCallback function){
+gboolean community_utilities_add_single_button(ClutterActor* button, ClutterContainer* list, char* path, int width, int height, GCallback function){
+	//printf("community_utilities_add_single_button '%s'\n",path);
 	button = tangle_button_new_with_background_actor(tangle_texture_new(path));
 	clutter_actor_set_name(button, path);
 	clutter_container_add_actor(list, button);
@@ -548,44 +569,38 @@ void community_utilities_clear_songlist(GList* songs){
  * -suffix defines which type of files will be sorted, other files are ignored
  *   (if suffix is "DIR", only directories are listed)
  * -result is an array of strings that contains filenames in order when this funtion returns
+ *   Caller must free it after use.
  *
  * returns number of files found
 **/
-int community_utilities_open_and_arrange_dir(const char* path, char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
+int community_utilities_open_and_arrange_dir(const char* path, const char* suffix, char result[MAX_FILES_IN_DIR][MAX_FILE_NAME_LEN]){
 	DIR *dir;
 	struct dirent *dir_ent;
 	int numberOfFiles = 0;
 	dir = opendir(path);
 
-	if(dir != NULL){
-	
-		if(strcmp(suffix, "DIR") == 0){
-		
-			for(numberOfFiles = 0; (dir_ent = readdir(dir)) != 0; numberOfFiles++){
-			
-				if(strstr(dir_ent->d_name, ".") != 0 || strstr(dir_ent->d_name, "..") != 0)
+	if(dir != NULL){  //Error checking
+		for(numberOfFiles = 0; (dir_ent = readdir(dir)) != 0; numberOfFiles++){
+			if(strcmp(suffix, "DIR") == 0){  //Asked subdirectories
+				if(strstr(dir_ent->d_name, ".") != 0 || strstr(dir_ent->d_name, "..") != 0) {
 					numberOfFiles--;
-
-				else strcpy(result[numberOfFiles], dir_ent->d_name);
-
-			}
-		
-		}else{
-			for(numberOfFiles = 0; (dir_ent = readdir(dir)) != 0; numberOfFiles++){
-			
-				if(strstr(dir_ent->d_name, suffix) == 0)
+					continue;
+				}
+			}else{   //Asked files with suffix
+				if(strstr(dir_ent->d_name, suffix) == 0) {
 					numberOfFiles--;
-			
-				else	strcpy(result[numberOfFiles], dir_ent->d_name);	
-
+					continue;
+				}
 			}
+			//take this
+			strcpy(result[numberOfFiles], dir_ent->d_name);
 		}
+
 		qsort(result, numberOfFiles, MAX_FILE_NAME_LEN, (void*)strcoll);
-	
 		closedir(dir);
 	}
-	return numberOfFiles;
 
+	return numberOfFiles;
 }
 
 /**
@@ -736,7 +751,7 @@ gboolean community_utilities_parse_songs_from_file(const gchar* filename, GList*
 			const gchar* track_filename =  "";
 			//gchar* info_filename = "";
 			const gchar* label =  "";
-			gchar* comments =  "";
+			const gchar* comments =  "";
 			const gchar* date =  "";
 
 			printf("\nFound track!\n");
@@ -759,7 +774,7 @@ gboolean community_utilities_parse_songs_from_file(const gchar* filename, GList*
 
 				sub_node = json_object_get_member(sub_object, "loopid"); 
 				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
-					id = (gchar*)json_node_get_string(sub_node);
+					id = json_node_get_string(sub_node);
 					printf("loopid: '%s'\n", id);
 				}		
 				sub_node = json_object_get_member(sub_object, "loopname");
@@ -800,7 +815,7 @@ gboolean community_utilities_parse_songs_from_file(const gchar* filename, GList*
 				sub_node = json_object_get_member(sub_object, "comments"); 
 			
 				if (sub_node != NULL && JSON_NODE_TYPE(sub_node) == JSON_NODE_VALUE){
-					comments = (gchar*)json_node_get_string(sub_node);
+					comments = json_node_get_string(sub_node);
 					printf("comments path: '%s'\n", comments);
 				}
 			}
