@@ -14,7 +14,6 @@ This is the sequencer.
 #include "jammosongs.h"
 #include "workshops.h"
 #include "jammosounds.h"
-#include "help.h"
 #include "discuss.h"
 #include "avatar_editor.h"
 
@@ -39,7 +38,6 @@ gboolean start_communitymenu()
 		tangle_actor_show(TANGLE_ACTOR(jammo_get_actor_by_id("communitymenu_goto_jammosongs")));		
 		tangle_actor_show(TANGLE_ACTOR(jammo_get_actor_by_id("communitymenu_goto_workshops")));
 		tangle_actor_show(TANGLE_ACTOR(jammo_get_actor_by_id("communitymenu_goto_jammosounds")));
-		tangle_actor_show(TANGLE_ACTOR(jammo_get_actor_by_id("communitymenu_goto_help")));
 		tangle_actor_show(TANGLE_ACTOR(jammo_get_actor_by_id("communitymenu_goto_discuss")));
 		
 		
@@ -88,16 +86,6 @@ gboolean communitymenu_goto_jammosounds(TangleButton* tanglebutton, gpointer non
 }
 
 
-gboolean communitymenu_goto_help(TangleButton* tanglebutton, gpointer none){
-	
-	cem_add_to_log("communitymenu_goto_helpdesk", J_LOG_DEBUG);
-	
-	start_helpdesk(); 
-
-	return TRUE;
-}
-
-
 gboolean communitymenu_goto_discuss(TangleButton* tanglebutton, gpointer none){
 	
 	cem_add_to_log("communitymenu_goto_discuss", J_LOG_DEBUG);
