@@ -14,6 +14,7 @@ This file contains the functionality of JamMo Songs menu.
 #include "profile_viewer.h"
 #include "../../gems/gems_utils.h"
 #include "../../cem/cem.h"
+#include "avatar_editor.h"
 
 static list_type list = {0, 0};
 GList *paramsList = 0;
@@ -133,8 +134,10 @@ gboolean add_song_to_list(gpointer data, guint32 user_id){
 		avatar_id = 260; //default avatar
 		
 	avatar_unserialize_image(&avatar, avatar_id);
-	avatar_shrink(&avatar, CLUTTER_CONTAINER(avatarBackground));
-	
+
+	set_avatar(&avatar, CLUTTER_ACTOR(avatarBackground));
+	avatar_shrink(&avatar);
+
 	clutter_container_add_actor(listContainer, composer);
 	
 	clutter_container_add_actor(listContainer, songName);
@@ -231,7 +234,7 @@ void review_selected_song(ClutterActor *song){
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 
-	start_thread_view(/*messages, */"jammosongs", (gchar*)comments_filepath, 0);
+	start_thread_view("jammosongs", comments_filepath, 0);
 }
 
 
