@@ -496,6 +496,10 @@ static gboolean on_dropping_incompatible_sample(JammoEditingTrackView* track_vie
 		//mentor: this is rhythm-track, drop melodic-loop to melodic-track
 		jammo_mentor_speak(jammo_mentor_get_default(), "t1_6_helpB.spx");
 	}
+	else if (type==JAMMO_SAMPLE_RHYTMICAL){
+		//mentor: this is  melodic-track, drop rhytmic-loop to rhytmic-track
+		jammo_mentor_speak(jammo_mentor_get_default(), "t1_6_helpC.spx");
+	}
 	else {
 		//It is better to place different instruments on their own tracks
 		jammo_mentor_speak(jammo_mentor_get_default(), "incompatible_track_type.spx");
