@@ -70,7 +70,7 @@ void sequencer_set_group_composition(JammoCollaborationGroupComposition* pc) {
 	static_group_composition=pc;
 }
 
-static void load_state_from_file(gchar* filename, gboolean load_only_backingtrack) {
+static void load_state_from_file(const gchar* filename, gboolean load_only_backingtrack) {
 
 JsonParser *parser;
 parser = json_parser_new ();
@@ -427,7 +427,7 @@ static void levelview_loaded(ClutterActor *levelview, gpointer none) {
 
 }
 
-void sequencer_start_with_file(gchar* filename) {
+void sequencer_start_with_file(const gchar* filename) {
 	gamesmenu_show(); //When level starts, it suppose that gamesmenu is also visible
 	gamesmenu_start_first_task_on_this_level("empty-level");
 
