@@ -18,6 +18,7 @@
 #include "mysongs.h"
 #include "profile_viewer.h"
 #include "avatar.h"
+#include "avatar_editor.h"
 
 static ClutterContainer *messageList = 0;
 static int selected_index = 0;
@@ -46,11 +47,11 @@ static void record_voice_comment();
 static void stop_recording();
 
 
-void start_thread_view(gchar *id_, const gchar *params, int index_)
+void start_thread_view(const gchar *id_, const gchar *params, int index_)
 {
 	GList *l = 0; //Iterator
 	selected_index 	= index_;
-	static_id = id_;
+	static_id = g_strdup_printf("%s", id_);  //FIXME: is this leaking?
 	int numberOfMessages = 0;
 	st_messages = 0;
 
@@ -151,7 +152,9 @@ static void add_message_to_list(gpointer data, int i)  {
 		ClutterActor* date = clutter_text_new_full(TEXT_NORMAL, msg->time, &text_color);
 		//ClutterActor* avatar_ = clutter_text_new_full(TEXT_SMALL, msg->avatar, &text_color);
 
-		avatar_shrink(&avatar, CLUTTER_CONTAINER(avatarBackground));
+		set_avatar(&avatar, CLUTTER_ACTOR(avatarBackground));
+		avatar_shrink(&avatar);
+
 		clutter_container_add_actor(CLUTTER_CONTAINER(listContainer), writer);
 		
 		//index = (index+1) % 3;
@@ -586,13 +589,15 @@ static gboolean single_thread_send_message(int type_) {
 	}
 
 	gboolean returnvalue = FALSE;
-	gchar *msg = "";
-	gchar* comment_filepath = "";
-	gchar* newname;
+	gchar* msg = g_strdup_printf(" ");
+	gchar* comment_filepath = g_strdup_printf(" ");
+	gchar* newname = g_strdup_printf(" ");
 	//gint index = selected_index;
 
-	if(type_ == TEXT_COMMENT)
-		msg = g_strdup_printf("%s", (gchar*)clutter_text_get_text(CLUTTER_TEXT(text.text))); 
+	if(type_ == TEXT_COMMENT) {
+		g_free(msg);
+		msg = g_strdup_printf("%s", clutter_text_get_text(CLUTTER_TEXT(text.text)));
+	}
 
 	gint indexOfMessage = 0;
 
@@ -612,8 +617,10 @@ static gboolean single_thread_send_message(int type_) {
 
 	guint32 id = TEST_USERID; // TODO: use gems_profile_manager_get_userid(NULL)
 
-	if(type_ == VOICE_COMMENT){	
+	if(type_ == VOICE_COMMENT){
+		g_free(comment_filepath);
 		comment_filepath = g_strdup_printf("%s/last_recorded.ogg", configure_get_temp_directory());
+		g_free(newname);
 		newname = g_strdup_printf("%s/voice_comment_%d_%s.ogg", configure_get_temp_directory(),id, date);
 		rename(comment_filepath, newname);
 	}
@@ -736,15 +743,10 @@ static gboolean single_thread_send_message(int type_) {
 	if(sendJammoMessage(json))
 		returnvalue = TRUE;
 
-	if(strcmp(comment_filepath, "") != 0)
-		g_free(comment_filepath);
+	g_free(comment_filepath);
+	g_free(msg);
+	g_free(newname);
 
-	if(strcmp(msg, "") != 0)
-		g_free(msg);
-
-	if((type == VOICE_COMMENT)){
-		g_free(newname);
-	}
 	g_free(dest_filepath);
 	g_free(title);
 	g_free(sender);
