@@ -312,19 +312,19 @@ void load_this_sample_array_to_this_track_view(JsonNode *sub_node,JammoEditingTr
 			if (sample_node!=NULL && JSON_NODE_TYPE(sample_node) == JSON_NODE_OBJECT){
 				JsonObject* sample_object = json_node_get_object(sample_node);
 				gint slot=-1;
-				gchar* image_file=NULL;
-				gchar* audio_file=NULL;
+				const gchar* image_file=NULL;
+				const gchar* audio_file=NULL;
 
 				//string
 				sub_node = json_object_get_member (sample_object, "image");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					image_file =(gchar*)  json_node_get_string (sub_node);
+					image_file = json_node_get_string (sub_node);
 					//printf("image: '%s'\n",image_file);
 				}
 				//string
 				sub_node = json_object_get_member (sample_object, "audio");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					audio_file =(gchar*)  json_node_get_string (sub_node);
+					audio_file = json_node_get_string (sub_node);
 					//printf("audio: '%s'\n",audio_file);
 				}
 
@@ -380,8 +380,8 @@ void load_this_sample_array_to_this_track_view_legacy2(JsonNode *sub_node,JammoE
 			if (sample_node!=NULL && JSON_NODE_TYPE(sample_node) == JSON_NODE_OBJECT){
 				JsonObject* sample_object = json_node_get_object(sample_node);
 				gint slot=-1;
-				gchar* image_file=NULL;
-				gchar* audio_file=NULL;
+				const gchar* image_file=NULL;
+				const gchar* audio_file=NULL;
 
 				//string
 				sub_node = json_object_get_member (sample_object, "image");
@@ -392,7 +392,7 @@ void load_this_sample_array_to_this_track_view_legacy2(JsonNode *sub_node,JammoE
 				//string
 				sub_node = json_object_get_member (sample_object, "audio");
 				if (sub_node!=NULL && JSON_NODE_TYPE (sub_node) == JSON_NODE_VALUE){
-					audio_file =(gchar*)  json_node_get_string (sub_node);
+					audio_file = json_node_get_string (sub_node);
 					//printf("audio: '%s'\n",audio_file);
 				}
 
