@@ -747,26 +747,31 @@ static gboolean is_droppable(JammoEditingTrackView* track_view, TangleDragAction
 			center_x -= (*n_slots_return - 1) * track_view->priv->real_slot_width / 2;
 			*slot_return = center_x / track_view->priv->real_slot_width;
 
-			if (*slot_return >= track_view->priv->disabled_slots_begin &&
-			    *slot_return + *n_slots_return - 1 < track_view->priv->n_slots - track_view->priv->disabled_slots_end &&
-			    !check_if_overlapping(track_view, meta_actor, *slot_return)) {
-				droppable = TRUE;
-			}
-
 			//slot_return is guint, it is possible it is 'negative', which then means 'something big'
 			if (*slot_return > 100000) {
-				droppable = FALSE;
+				return FALSE;
 			}
 
-			//Waltz-samples can be dropped to any beat, non-waltz only to first beat of bar
-			else if (!jammo_sample_button_is_waltz(JAMMO_SAMPLE_BUTTON(meta_actor)) && (*slot_return%4!=0)){
+			//Check 'rounding' to the first beat of the bar
+			//non-waltz-samples is always rounded
+			//waltz-samples is not rounded if previous slot is occupied
+			if (!(jammo_sample_button_is_waltz(JAMMO_SAMPLE_BUTTON(meta_actor))  &&
+			      check_if_overlapping(track_view, CLUTTER_ACTOR(meta_actor), *slot_return-1) ))
+				{
 				if (*slot_return%4 == 1)
 					*slot_return-=1;
 				else if (*slot_return%4 == 2)
 					*slot_return+=2;
 				else if (*slot_return%4 == 3)
 					*slot_return+=1;
+				}
+
+			if (*slot_return >= track_view->priv->disabled_slots_begin &&
+			    *slot_return + *n_slots_return - 1 < track_view->priv->n_slots - track_view->priv->disabled_slots_end &&
+			    !check_if_overlapping(track_view, meta_actor, *slot_return)) {
+				droppable = TRUE;
 			}
+
 		}
 	}
 	
@@ -854,15 +859,21 @@ static void on_dropped(TangleDropAction* drop_action, TangleDragAction* drag_act
 		center_x -= (n_slots - 1) * track_view->priv->real_slot_width / 2;
 		slot = center_x / track_view->priv->real_slot_width;
 
-		//Waltz-samples can be dropped to any beat, non-waltz only to first beat of bar
-		if (!jammo_sample_button_is_waltz(JAMMO_SAMPLE_BUTTON(sample_button))) {
-			if (slot%4 == 1)
-				slot-=1;
-			else if (slot%4 == 2)
-				slot+=2;
-			else if (slot%4 == 3)
-				slot+=1;
-		}
+
+		//Check 'rounding' to the first beat of the bar
+		//non-waltz-samples is always rounded
+		//waltz-samples is not rounded if previous slot is occupied
+		if (!(jammo_sample_button_is_waltz(JAMMO_SAMPLE_BUTTON(sample_button))  &&
+		    check_if_overlapping(track_view, CLUTTER_ACTOR(meta_actor), slot-1) ))
+			{
+				if (slot%4 == 1)
+					slot-=1;
+				else if (slot%4 == 2)
+					slot+=2;
+				else if (slot%4 == 3)
+					slot+=1;
+			}
+
 
 		jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(copy_of_sample_button)), slot * get_duration_of_slot(track_view->priv->track));
 
