@@ -10,6 +10,7 @@ static gchar* SINGINGS_DIRECTORY=NULL;     //3-6 singings
 static gchar* PROJECTS_DIRECTORY=NULL;     //7-12 working versions
 static gchar* FINALIZED_DIRECTORY=NULL;    //7-12 audio files
 static gchar* LOG_DIRECTORY=NULL;    	   //Log files
+static gchar* COMMUNITY_TEMP_DIRECTORY=NULL;//Used to hold community's temporary files
 
 static void make_directory(gchar* directory) {
 	gchar* cmd;
@@ -62,9 +63,11 @@ void configure_init_directories(gboolean small_game){
 		PROJECTS_DIRECTORY = g_strdup_printf("%s/projects",JAMMO_DIRECTORY);
 		FINALIZED_DIRECTORY = g_strdup_printf("%s/finalized",JAMMO_DIRECTORY);
 		LOG_DIRECTORY = g_strdup_printf("%s/logs7_12",JAMMO_DIRECTORY);
+		COMMUNITY_TEMP_DIRECTORY = g_strdup_printf("%s/community_temp",JAMMO_DIRECTORY);
 
 		make_directory(PROJECTS_DIRECTORY);
 		make_directory(FINALIZED_DIRECTORY);
+		make_directory(COMMUNITY_TEMP_DIRECTORY);
 	}
 
 	make_directory(LOG_DIRECTORY);
@@ -104,6 +107,7 @@ void configure_release_directories(){
 	if (PROJECTS_DIRECTORY) g_free(PROJECTS_DIRECTORY);
 	if (FINALIZED_DIRECTORY) g_free(FINALIZED_DIRECTORY);
 	if (LOG_DIRECTORY) g_free(LOG_DIRECTORY);
+	if (COMMUNITY_TEMP_DIRECTORY) g_free(COMMUNITY_TEMP_DIRECTORY);
 }
 
 
@@ -130,3 +134,6 @@ const gchar* configure_get_finalized_directory(){
 const gchar* configure_get_log_directory(){
 	return LOG_DIRECTORY;
 }
+const gchar* configure_get_temp_directory(){
+	return COMMUNITY_TEMP_DIRECTORY;
+}
