@@ -20,6 +20,10 @@
 #include <iterator>
 #include <glib.h>
 
+extern "C" {
+	#include "gems_definitions.h"
+}
+
 using namespace std;
 
 class StorageAgent 
@@ -74,7 +78,7 @@ public:
 	
 	void clearEncryptedData();
 
-	gint readProfile(const gchar* username);
+	GemsProfileLoadAction readProfile(const gchar* username);
 	gint writeProfile(const gchar* username);
 	
 private:
