@@ -35,6 +35,14 @@
 #define BUFFER_SIZE         1000
 #define JAMMOPORT		5555
 
+/**
+ * gems_communication_init:
+ *
+ * Initialize GEMS communication structures. Initializes the 
+ * #gems_communication_data structure and lists in the structure.
+ *
+ * Returns: Pointer to initialized structure.
+ */
 gems_communication_data* gems_communication_init()
 {
 	// Communication data struct
@@ -52,6 +60,15 @@ gems_communication_data* gems_communication_init()
 	return data;
 }
 
+/**
+ * gems_communication_cleanup:
+ *
+ * Clean all GEMS communication data. Cleans up the lists by calling 
+ * gems_communication_cleanup_lists() and frees the #gems_communication_data 
+ * structure retrieved with gems_get_data() .
+ *
+ * Returns: void
+ */
 void gems_communication_cleanup()
 {	
 	gems_communication_data* data = gems_get_data()->communication;
@@ -64,6 +81,14 @@ void gems_communication_cleanup()
 	data = NULL;
 }
 
+/**
+ * gems_communication_cleanup_lists:
+ *
+ * Clean all lists inside the #gems_communication_data structure. Destroys every
+ * #gems_connection structure pointed the lists. 
+ *
+ * Returns: void
+ */
 void gems_communication_cleanup_lists()
 {
 	gems_communication_data* data = gems_get_data()->communication;
@@ -90,6 +115,24 @@ void gems_communication_cleanup_lists()
 	}
 }
 
+/**
+ * gems_communication_search_jammos:
+ *
+ * Search new JamMos from environment. This function is added to Glib main loop
+ * and is executed periodically. Requests a list of devices having "JamMo"
+ * service enabled from PeerHood. If the list returned by PeerHood library is 
+ * NULL the connection to PeerHood is determined to be closed and function 
+ * gems_communication_peerhood_close_detected() is called to enable the probing
+ * of Peerhood. When the list is not empty or null a connection is attempted
+ * to be established to every new device. The connection will be attempted to
+ * be establish with gems_communication_establish_connection() if the device is
+ * not found from any of the internal lists, function 
+ * gems_communication_already_connected() is used for checking.
+ *
+ * Returns: Integer values 0 (FALSE) or 1 (TRUE), 0 in case of errors when the
+ * function is removed from the Glib main loop. Triggering errors are: data 
+ * components not initialized or set, or the connection to PeerHood is lost.
+ */
 gint gems_communication_search_jammos()
 {
 	gchar* logmsg = NULL;
@@ -152,6 +195,22 @@ gint gems_communication_search_jammos()
 	return TRUE;
 }
 
+/**
+ * gems_communication_establish_connection:
+ * @device: Device to establish connection to, a pointer to structure which
+ * points to the actual C++ object that is handled by PeerHood library.
+ *
+ * Attempts to establish connection to given @device if there aren't any errors
+ * preventing the connection, uses gems_connection_error_attempt_connection() 
+ * to check. When connection establishment is succesfull the connection will
+ * be added to initialized connections list in #gems_communication_data ,
+ * otherwise the checksum of the device will be added to connection errorlist
+ * and the connection is disconnected and deleted. The #jammo_state will be set
+ * to %JAMMO_WAITING_REQUEST after succesfull send of %CONNECT_REQ message.
+ *
+ * Returns: a #gboolean , TRUE when connection was established, FALSE
+ * otherwise.
+ */
 gboolean gems_communication_establish_connection(MAbstractDevice* device)
 {
 	gchar* logmsg = NULL;
@@ -229,6 +288,20 @@ gboolean gems_communication_establish_connection(MAbstractDevice* device)
 	}
 }
 
+/**
+ * gems_communication_retrieve_profiles:
+ *
+ * Requests the public profile from surrounding devices. A timeout function 
+ * executed periodically by the Glib main loop. The request is sent to
+ * connected devices which are in %JAMMO_CONNECTED_AUTH #jammo_state if the 
+ * public profile is not received yet. The request is sent using a timer with
+ * interval defined in %PROFILE_REQUEST_INTERVAL if the profile isn't received.
+ * In case of errorous write the connection is disconnected to the particular
+ * device.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_retrieve_profiles()
 {
 	gems_components* data = gems_get_data();
@@ -292,6 +365,18 @@ gint gems_communication_retrieve_profiles()
 	return TRUE;
 }
 
+/**
+ * gems_communication_request_groups:
+ * 
+ * Request group info from connected devices. A timeout function executed
+ * periodically by the Glib main loop. Sends group information requests to
+ * every connected (in %JAMMO_CONNECTED_AUTH #jammo_state) device with interval
+ * defined in %GROUP_REQUEST_INTERVAL . In case of errorous write the 
+ * connection is disconnected to the particular device.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_request_groups()
 {
 	gems_components* data = gems_get_data();
@@ -358,6 +443,17 @@ gint gems_communication_request_groups()
 	return TRUE;
 }
 
+/**
+ * gems_communication_advert_group:
+ *
+ * Advert group info to connected devices. A timeout function executed
+ * periodically by the Glib main loop. Sends group advertizements to
+ * every connected (in %JAMMO_CONNECTED_AUTH #jammo_state) device with interval
+ * defined in %GROUP_ADVERT_INTERVAL .
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_advert_group()
 {
 	gems_components* data = gems_get_data();
@@ -426,6 +522,15 @@ gint gems_communication_advert_group()
 	return TRUE;
 }
 
+/**
+ * gems_communication_sanitize_grouplist:
+ *
+ * Function for removing old group information from the group list. A timeout
+ * function executed periodically by Glib main loop. Removes group information
+ * from the list if it is not updated for %GROUP_REMOVE_LIMIT seconds.
+ *
+ * Returns: 1 (TRUE) always.
+ */
 gint gems_communication_sanitize_grouplist()
 {
 	gems_components* data = gems_get_data();
@@ -467,6 +572,17 @@ gint gems_communication_sanitize_grouplist()
 	return TRUE;
 }
 
+/**
+ * gems_communication_process_connecting:
+ *
+ * Process connections intialized to other devices. A timeout function executed
+ * periodically by the Glib main loop. Uses the "JamMo" service connection
+ * processing function (gems_service_jammo_process_list()) to execute the
+ * handshake procedure between connecting devices.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_process_connecting()
 {
 	gems_components* data = gems_get_data();
@@ -480,6 +596,16 @@ gint gems_communication_process_connecting()
 	return TRUE;
 }
 
+/**
+ * gems_communication_process_rejected:
+ *
+ * Process rejected connections list. A timeout function executed periodically
+ * by the Glib main loop. Calls gems_process_rejected() to check the list of
+ * rejected devices.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_process_rejected()
 {
 	gems_components* data = gems_get_data();
@@ -493,6 +619,17 @@ gint gems_communication_process_rejected()
 	return TRUE;
 }
 
+/**
+ * print_list:
+ * @list: list to print, must contain only pointers to #gems_connection structs
+ *
+ * Print the contents of given list to stdout. List must contain only pointers
+ * to #gems_connection structs. Used only for debug.
+ *
+ * Returns: void
+ *
+ * Deprecated: 0.5: Do not use.
+ */
 void print_list(GList* list)
 {
 	GList* iterator = NULL;
@@ -522,6 +659,16 @@ void print_list(GList* list)
 	}
 }
 
+/**
+ * print_group:
+ * @info: group info structure to print
+ *
+ * Print the contents of given #gems_group_info to stdout. Used only for debug.
+ *
+ * Returns: void
+ *
+ * Deprecated: 0.6: Do not use.
+ */
 void print_group(gems_group_info* info)
 {
 	printf("gid:\t%u\nowner:\t%u\ntype:\t%d\ntheme:\t%d\nsize:\t%d\nspaces\t%d\nlocked:\t%s\n",
@@ -556,7 +703,17 @@ void print_group(gems_group_info* info)
 	for(i = 0; i < (GROUP_MAX_SIZE - 1); i++)	printf("(%d)\t%u\n",i,members[i]);
 }
 
-gint gems_communication_already_connected(guint checksum)
+/**
+ * gems_communication_already_connected:
+ * @checksum: Checksum of the device to search from lists.
+ *
+ * Check if the given device with @checksum is already in some list. Uses
+ * gems_communication_search_from_list() to check every possible list which
+ * contains pointers to #gems_connection structs.
+ *
+ * Returns: the result of the list search as #connection_search enum value.
+ */
+connection_search gems_communication_already_connected(guint checksum)
 {
 	gems_components* data = gems_get_data();
 	
@@ -580,9 +737,20 @@ gint gems_communication_already_connected(guint checksum)
 	return NOT_IN_LIST;
 }
 
+/**
+ * gems_communication_search_from_list:
+ * @list: the list to search, must contain only pointers to #gems_connection
+ * structs
+ * @checksum: Device checksum to search from given list
+ *
+ * Search a connection with given @checksum from the given @list.
+ *
+ * Returns: a #gboolean, TRUE if found, FALSE if not found or list is empty.
+ */
 gboolean gems_communication_search_from_list(GList* list, guint checksum)
 {
 	GList* iterator = NULL;
+	if(!list) return FALSE; // No list given
 	if(g_list_length(list) == 0) return FALSE;
 	// Search the list
 	for(iterator = g_list_first(list); iterator; iterator = g_list_next(iterator))
@@ -601,9 +769,20 @@ gboolean gems_communication_search_from_list(GList* list, guint checksum)
 	return FALSE;
 }
 
+/**
+ * gems_communication_get_connection:
+ * @list: the list to search, must contain only pointers to #gems_connection
+ * structs
+ * @checksum: Device checksum to search from given list
+ *
+ * Search a connection with given @checksum from the given @list and return it.
+ *
+ * Returns: a pointer to #gems_connection structure if found, NULL otherwise.
+ */
 gems_connection* gems_communication_get_connection(GList* list, guint checksum)
 {
 	GList* iterator = NULL;
+	if(!list) return NULL; // No list given
 	if(g_list_length(list) == 0) return NULL; // empty
 	
 	// Search the list
@@ -619,9 +798,22 @@ gems_connection* gems_communication_get_connection(GList* list, guint checksum)
 	return NULL; // Not found
 }
 
+/**
+ * gems_communication_get_connection_with_userid:
+ * @list: the list to search, must contain only pointers to #gems_connection
+ * structs
+ * @userid: Id fof the user to search from given list
+ *
+ * Search a connection from the given @list where the user id in the public
+ * profile (#gems_peer_profile) matches the given @userid. When found return a
+ * pointer to that #gems_connection.
+ *
+ * Returns: a pointer to #gems_connection structure if found, NULL otherwise.
+ */
 gems_connection* gems_communication_get_connection_with_userid(GList* list, guint32 userid)
 {
 	GList* iterator = NULL;
+	if(!list) return NULL; // No list given
 	if(g_list_length(list) == 0) return NULL; // empty
 	
 	// Search the list
@@ -641,57 +833,130 @@ gems_connection* gems_communication_get_connection_with_userid(GList* list, guin
 	return NULL; // Not found
 }
 
+/**
+ * gems_communication_process_new:
+ * @element: New connection element to add.
+ *
+ * Add new #gems_connection to list of established connections.
+ *
+ * Returns: void
+ */
 void gems_communication_process_new(gems_connection* element)
 {
-	gems_communication_data* data = gems_get_data()->communication;
-	data->connections = g_list_append(data->connections, element);
-	gchar* logmsg = g_strdup_printf("gems_communication_process_new: added new (%s/%u)",
-		ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
-	cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
-	g_free(logmsg);
+	if(element)
+	{
+		gems_communication_data* data = gems_get_data()->communication;
+		data->connections = g_list_append(data->connections, element);
+		gchar* logmsg = g_strdup_printf("gems_communication_process_new: added new (%s/%u)",
+			ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+		g_free(logmsg);
+	}
 }
 
+/**
+ * gems_communication_process_new_rejected:
+ * @element: New rejected connection element to add.
+ *
+ * Add new rejected connection (#gems_connection) to list of established 
+ * connections.
+ *
+ * Returns: void
+ */
 void gems_communication_process_new_rejected(gems_connection* element)
 {
-	gems_communication_data* data = gems_get_data()->communication;
-	gems_connection_set_action(element); // Record the time this connection was rejected
-	data->rejected = g_list_append(data->rejected, element);
-	gchar* logmsg = g_strdup_printf("gems_communication_process_new_rejected: added new element (%s/%u) to rejected list",
-		ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
-	cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
-	g_free(logmsg);
+	if(element)
+		{
+		gems_communication_data* data = gems_get_data()->communication;
+		gems_connection_set_action(element); // Record the time this connection was rejected
+		data->rejected = g_list_append(data->rejected, element);
+		gchar* logmsg = g_strdup_printf("gems_communication_process_new_rejected: added new element (%s/%u) to rejected list",
+			ph_c_connection_get_remote_address(element->connection),ph_c_connection_get_device_checksum(element->connection));
+		cem_add_to_log(logmsg, J_LOG_NETWORK_DEBUG);
+		g_free(logmsg);
+	}
 }
 
+/**
+ * gems_communiaction_write_encrypted_data:
+ * @type: Type of the encrypted message, can be either %JAMMO_PACKET_PRIVATE or
+ * %JAMMO_PACKET_ADMIN (%JAMMO_PACKET_GROUP not implemented).
+ * @element: The connection element where data is written to.
+ * @data: The message to be written, length and content must be appropriately
+ * set.
+ *
+ * Write given message @data to connection @element inside encrypted envelope.
+ * The envelope is created using the given message @data using 
+ * gems_security_create_envelope() . If the full length of the encrypted
+ * message cannot be written FALSE is returned. The message @data is not
+ * touched and must be free'd by the caller function. Write operation is 
+ * performed by calling gems_communication_write_data() .
+ *
+ * Returns: a #gboolean, TRUE when the envelope was created and all data was
+ * written. FALSE when either of the operations failed.
+ */
 gboolean gems_communication_write_encrypted_data(guint16 type, gems_connection* element, gems_message* data)
 {
 	gboolean success = TRUE;
 	gems_message* envelope = gems_security_create_envelope(type, element, data);
 	
-	if((gems_communication_write_data(ph_c_connection_get_fd(element->connection), envelope)) != envelope->length)
+	if(envelope)
 	{
-		success = FALSE;
+		if((gems_communication_write_data(ph_c_connection_get_fd(element->connection), envelope)) != envelope->length) success = FALSE;
+		gems_clear_message(envelope);
 	}
-	
-	gems_clear_message(envelope);
-	envelope = NULL;
+	else success = FALSE;
 	
 	return success;
 }
 
-// Write message to socket
+/**
+ * gems_communication_write_data:
+ * @sock_fd: Socket where the data is written to
+ * @data: Message to write
+ *
+ * Write given message (@data) to given socket (@sock_fd).
+ *
+ * Returns: Amount of bytes written, -1 in case of errors.
+ */
 gint gems_communication_write_data(gint sock_fd, gems_message* data)
 {
 	if(!data) return -1;
+	if(sock_fd < 0) return -1;
 	return write(sock_fd, (gchar*)data->message, data->length);
 }
 
-// Read data from socket, place data in gpointer* data
+/**
+ * gems_communication_read_data:
+ * @sock_fd: Socket where to read from.
+ * @data: Buffer to store read data, must be at least the length of @length
+ * parameter, data is read as #gchar:s into buffer.
+ * @length: Amount of data to read into @data.
+ *
+ * Read data from socket, place read bytes in @data. Data is read as #gchar:s.
+ *
+ * Returns: Amount of bytes read.
+ */
 gint gems_communication_read_data(gint sock_fd, void* data, gint length)
 {
 	if(!data || length == 0) return -1;
+	if(sock_fd < 0) return -1;
 	return read(sock_fd, (gchar*)data, length);
 }
-
+/**
+ * gems_communication_process_connected:
+ *
+ * Processes all connections which have inbound data, reads the data in pieces
+ * and forwards full packets for to gems_communication_process_data() for 
+ * processing. The teacher connection (if exists) is checked first then other
+ * devices are processed. A timeout function which is executed periodically by
+ * Glib main loop, removes itself from the loop in case of errors with internal
+ * data. Disconnects all connections which have either invalid header or the
+ * data cannot be read from connection.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_process_connected()
 {
 	gems_components* data = gems_get_data();
@@ -942,11 +1207,28 @@ gint gems_communication_process_connected()
 		else iterator = g_list_next(iterator);
 	}
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
-	if(teacher_cleanup_required) gems_teacher_connection_disconnect();
+	if(teacher_cleanup_required) gems_teacher_connection_disconnected();
 	
 	return TRUE;
 }
 
+/**
+ * gems_communication_process_data:
+ * @element: connection which has a full packet waiting
+ *
+ * Processes the full packet waiting at the network buffer of connection
+ * @element. First the packet is extracted from the envelope with
+ * gems_security_extract_envelope() and the content is localized with 
+ * gems_connection_localize_data_in_buffer(). If the service id matches to
+ * certain handler the connection @element will be passed to that handler
+ * for processing the message content. Packets with invalid service id will
+ * be dropped, packets to services which are not enabled set the return value
+ * to FALSE. Connection @element:s containing error messages are forwareded to
+ * gems_communication_process_error(). The network buffer of the given @element
+ * will be cleared after processing.
+ *
+ * Returns: TRUE when the data was in proper form, FALSE if invalid.
+ */
 gboolean gems_communication_process_data(gems_connection* element)
 {
 	gems_components* data = gems_get_data();
@@ -1206,7 +1488,14 @@ gboolean gems_communication_process_data(gems_connection* element)
 	return success;
 }
 
-// TODO implement error checking in different states
+/**
+ * gems_communication_process_error:
+ * @element: Connection element containing error message in its network buffer
+ *
+ * Process the error message in the connection @element network buffer.
+ *
+ * Returns: void
+ */
 void gems_communication_process_error(gems_connection* element)
 {
 	gems_message* msg = NULL;
@@ -1330,7 +1619,7 @@ void gems_communication_process_error(gems_connection* element)
 										// Otherwise ignore
 										break;
 									
-									case NOT_IN_GROUP:
+									case NONE:
 										// IGNORE
 										break;
 									
@@ -1518,7 +1807,19 @@ void gems_communication_process_error(gems_connection* element)
 	}
 }
 
-
+/**
+ * gems_communication_probe_for_peerhood:
+ *
+ * Attempt to establish a new connection to PeerHood daemon via PeerHood
+ * library. A timeout function enabled only when the connection to PeerHood 
+ * has been lost and is executed periodically by Glib main loop. Re-enables the
+ * other timeout functions (gems_enable_network_timeout_functions()) and
+ * re-registers all services (gems_register_services()). When the connection is
+ * re-established it will remove self from the main loop.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_communication_probe_for_peerhood()
 {
 	gems_components* data = gems_get_data();
@@ -1568,7 +1869,15 @@ gint gems_communication_probe_for_peerhood()
 	}
 }
 
-
+/**
+ * gems_communication_peerhood_close_detected:
+ *
+ * Called when connection to PeerHood daemon is lost. Disables all services and
+ * cleans up the lists of services. Removes all timeout functions from Glib
+ * main loop. Enables the PeerHood probing timeout function.
+ *
+ * Returns: void
+ */
 void gems_communication_peerhood_close_detected()
 {
 	gchar* logmsg = NULL;
@@ -1609,6 +1918,13 @@ void gems_communication_peerhood_close_detected()
 	
 }
 
+/**
+ * gems_teacher_connection_init:
+ *
+ * Initialize new empty #gems_teacher_connection struct.
+ *
+ * Returns: a pointer to created #gems_teacher_connection struct.
+ */
 gems_teacher_connection* gems_teacher_connection_init()
 {
 	gems_teacher_connection* tc = g_new0(gems_teacher_connection,sizeof(gems_teacher_connection));
@@ -1618,7 +1934,15 @@ gems_teacher_connection* gems_teacher_connection_init()
 	return tc;
 }
 
-gboolean gems_teacher_connection_disconnect()
+/**
+ * gems_teacher_connection_disconnected:
+ *
+ * Empties the connection to teacher after disconnection. Does not free the
+ * structure containing teacher connection (#gems_teacher_connection).
+ * 
+ * Returns: TRUE when the connection did exist, FALSE otherwise.
+ */
+gboolean gems_teacher_connection_disconnected()
 {
 	gems_components* data = gems_get_data();
 	
@@ -1633,7 +1957,7 @@ gboolean gems_teacher_connection_disconnect()
 		
 		//data->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,100,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
 		
-		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnect: connection to teacher was disconnected. Teacher search re-enabled.");
+		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnected: connection to teacher was disconnected. Teacher search re-enabled.");
 		cem_add_to_log(logmsg,J_LOG_NETWORK);
 		g_free(logmsg);
 		
@@ -1642,6 +1966,13 @@ gboolean gems_teacher_connection_disconnect()
 	else return FALSE;
 }
 
+/**
+ * gems_clear_teacher_connection:
+ *
+ * Clear the teacher connection and delete the struct.
+ * 
+ * Returns: void
+ */
 void gems_clear_teacher_connection()
 {
 	gems_components* data = gems_get_data();
@@ -1665,6 +1996,15 @@ void gems_clear_teacher_connection()
 	
 }
 
+/**
+ * gems_communication_do_profile_request_to_teacher:
+ * @username: Username to use in profile request
+ *
+ * Send a profile request to teacher if the connection exists and teacher is
+ * connected. Use the given @username in the message.
+ * 
+ * Returns: TRUE if the request was created and sent, FALSE otherwise.
+ */
 gboolean gems_communication_do_profile_request_to_teacher(gchar* username)
 {
 	gboolean rval = TRUE;
@@ -1680,6 +2020,14 @@ gboolean gems_communication_do_profile_request_to_teacher(gchar* username)
 	return rval;
 }
 
+/**
+ * gems_communication_send_profile_to_teacher:
+ * 
+ * Send the full profile to teacher if the connection to teacher exists.
+ *
+ * Returns: TRUE if the message was sent, FALSE otherwise (or if there is no 
+ * connection to teacher).
+ */
 gboolean gems_communication_send_profile_to_teacher()
 {
 	if(gems_teacher_connection_is_connected())
@@ -1697,6 +2045,18 @@ gboolean gems_communication_send_profile_to_teacher()
 	}
 }
 
+/**
+ * gems_communication_search_teacher:
+ *
+ * A timeout function for searching teacher device from the surroundings. 
+ * Requests the list of devices with "JamMo:Mentor" service from PeerHood and
+ * attempts to create connection to first one that was found. 
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ *
+ * Deprecated: Not used.
+ */
 gint gems_communication_search_teacher()
 {
 	gchar* logmsg = NULL;
