@@ -29,9 +29,9 @@ gems_communication_data* gems_communication_init();
 void gems_communication_cleanup();
 void gems_communication_cleanup_lists();
 
-gboolean gems_communication_already_connected(guint checksum);
+connection_search gems_communication_already_connected(guint checksum);
 
-gint gems_communication_search_from_list(GList* list, guint checksum);
+gboolean gems_communication_search_from_list(GList* list, guint checksum);
 
 gems_connection* gems_communication_get_connection(GList* list, guint checksum);
 gems_connection* gems_communication_get_connection_with_userid(GList* list, guint32 userid);
@@ -72,7 +72,7 @@ gint gems_communication_probe_for_peerhood();
 void gems_communication_peerhood_close_detected();
 
 gems_teacher_connection* gems_teacher_connection_init();
-gboolean gems_teacher_connection_disconnect();
+gboolean gems_teacher_connection_disconnected();
 void gems_clear_teacher_connection();
 
 gboolean gems_communication_do_profile_request_to_teacher(gchar* username);
