@@ -34,7 +34,15 @@ static void empty_callback_group_control(gint type){}
 static void empty_callback_game(GObject * game, gint type, const gchar* song_info){}
 static void empty_callback_game_starter(gpointer data, gint16 track_id){}
 
-// A "singleton" get
+/**
+ * gems_get_data:
+ *
+ * Get the main GEMS struct, #gems_components. If the structure is not yet
+ * initialized new is created and all data is set with default values. Works
+ * almost in the same way as the Singleton pattern.
+ *
+ * Returns: a pointer to the main GEMS structure
+ */
 gems_components* gems_get_data()
 {
 	if(!gems_data)
@@ -67,37 +75,88 @@ gems_components* gems_get_data()
 	return gems_data;
 }
 
+/**
+ * gems_get_profile_manager:
+ *
+ * Get the profile manager
+ *
+ * Returns: a pointer to ProfileManager struct pointing to C++ object
+ */
 ProfileManager* gems_get_profile_manager()
 {
 	return profilemanager_get_manager();
 }
 
+/**
+ * gems_get_peerhood:
+ *
+ * Get PeerHood if it is enabled, NULL otherwise.
+ *
+ * Returns: a pointer to MPeerHood struct pointing to C++ object or NULL if it
+ * is not enabled.
+ */
 MPeerHood* gems_get_peerhood()
 {
 	if(gems_peerhood_enabled()) return gems_get_data()->ph;
 	else return NULL;
 }
 
+/**
+ * gems_peerhood_enabled:
+ *
+ * Check if the connection to PeerHood exists.
+ *
+ * Returns: TRUE when connection exists, FALSE otherwise.
+ */
 gboolean gems_peerhood_enabled()
 {
 	return gems_get_data()->ph_on;
 }
 
+/**
+ * gems_get_initialized_connections:
+ *
+ * Get the list of initialized connections (connections initialized by this
+ * device).
+ *
+ * Returns: a pointer to GList containing pointers to #gems_connection structs.
+ */
 GList* gems_get_initialized_connections()
 {
 	return gems_get_data()->initialized_connections;
 }
 
+/**
+ * gems_get_communication
+ *
+ * Get the communication data struct.
+ *
+ * Returns: a pointer to #gems_communication_data structure.
+ */
 gems_communication_data* gems_get_communication()
 {
 	return gems_get_data()->communication;
 }
 
+/**
+ * gems_get_security_contexts:
+ *
+ * Get the security context data struct.
+ *
+ * Returns: a pointer to #gems_security_context structure.
+ */
 gems_security_context* gems_get_security_contexts()
 {
 	return gems_get_data()->security_context;
 }
 
+/**
+ * gems_get_service_jammo:
+ *
+ * Get the JamMo service data struct.
+ *
+ * Returns: a pointer to #gems_service_jammo structure.
+ */
 gems_service_jammo* gems_get_service_jammo()
 {
 	return gems_get_data()->service_jammo;
@@ -109,74 +168,176 @@ gems_service_jammo* gems_get_service_jammo()
 	return NULL; 
 }*/
 
+/**
+ * gems_get_service_profile:
+ *
+ * Get the Profile service data struct.
+ *
+ * Returns: a pointer to #gems_service_profile structure.
+ */
 gems_service_profile* gems_get_service_profile()
 {
 	return gems_get_data()->service_profile;
 }
 
+/**
+ * gems_get_service_group:
+ *
+ * Get the Group Management service data struct.
+ *
+ * Returns: a pointer to #gems_service_group structure.
+ */
 gems_service_group* gems_get_service_group()
 {
 	return gems_get_data()->service_group;
 }
 
+/**
+ * gems_get_service_collaborarion:
+ *
+ * Get the Collaboration service data struct.
+ *
+ * Returns: a pointer to #gems_service_collaboration structure.
+ */
 gems_service_collaboration* gems_get_service_collaboration()
 {
 	return gems_get_data()->service_collaboration;
 }
 
+/**
+ * gems_get_service_control:
+ *
+ * Get the Control service data struct.
+ *
+ * Returns: a pointer to #gems_service_control structure.
+ */
 gems_service_control* gems_get_service_control()
 {
 	return gems_get_data()->service_control;
 }
 
+/**
+ * gems_get_service_mentor:
+ *
+ * Get the Mentor service data struct.
+ *
+ * Returns: a pointer to #gems_service_mentor structure.
+ */
 gems_service_mentor* gems_get_service_mentor()
 {
 	return gems_get_data()->service_mentor;
 }
 
+/**
+ * gems_get_errorlist
+ *
+ * Get the errorlist containing #gems_connection_error structures.
+ *
+ * Returns: a #GList of error connections.
+ */
 GList* gems_get_errorlist()
 {
 	return gems_get_data()->connection_errorlist;
 }
 
+/**
+ * gems_get_teacher_connection:
+ *
+ * Get the teacher connection data structure.
+ *
+ * Returns: pointer to #gems_teacher_connection struct.
+ */
 gems_teacher_connection* gems_get_teacher_connection()
 {
 	return gems_get_data()->teacher_connection;
 }
 
+/**
+ * gems_is_waiting_for_teacher:
+ *
+ * Check if this device is set for waiting for teacher.
+ *
+ * Returns: TRUE when waiting, FALSE otherwise.
+ */
 gboolean gems_is_waiting_for_teacher()
 {
 	return gems_get_data()->waiting_for_teacher;
 }
 
+/**
+ * gems_set_waiting_for_teacher:
+ *
+ * Set the device to wait for teacher.
+ *
+ * Returns: void
+ */
 void gems_set_waiting_for_teacher()
 {
 	// TODO call CHUM to "draw the curtain"
 	gems_get_data()->waiting_for_teacher = TRUE;
 }
 
+/**
+ * gems_unset_waiting_for_teacher:
+ *
+ * Set the device to not to wait for teacher.
+ *
+ * Returns: void
+ */
 void gems_unset_waiting_for_teacher()
 {
 	// TODO call CHUM to "remove curtain"
 	gems_get_data()->waiting_for_teacher = FALSE;
 }
 
+/**
+ * gems_is_waiting_profile_from_teacher:
+ *
+ * Check if the device is set to wait for a profile from teacher.
+ *
+ * Returns: TRUE if is set, FALSE otherwise.
+ */
 gboolean gems_is_waiting_profile_from_teacher()
 {
 	return gems_get_data()->waiting_profile_from_teacher;
 }
 
+/**
+ * gems_set_waiting_profile_from_teacher:
+ *
+ * Set the device to wait profile from teacher. Will be set after the profile
+ * is requested from teacher if it was not found on the local device.
+ *
+ * Returns: void.
+ */
 void gems_set_waiting_profile_from_teacher()
 {
 	gems_get_data()->waiting_profile_from_teacher = TRUE;
 }
 
+/**
+ * gems_unset_waiting_profile_from_teacher:
+ *
+ * Unset the device waiting for profile boolean. Reset the profile request
+ * counter.
+ *
+ * Returns: void
+ */
 void gems_unset_waiting_profile_from_teacher()
 {
 	gems_get_data()->waiting_profile_from_teacher = FALSE;
 	gems_reset_teacher_profile_request_counter();
 }
 
+/**
+ * gems_unset_teacher_profile_timeout_sid:
+ * @param: unused parameter
+ *
+ * Remote the profile request timeout function from Glib main loop and reset
+ * the profile request counter.
+ *
+ * Returns: void.
+ */
 void gems_unset_teacher_profile_timeout_sid(gpointer param)
 {
 	cem_add_to_log("Unset teacher profile timeout",J_LOG_NETWORK_DEBUG);
@@ -184,32 +345,78 @@ void gems_unset_teacher_profile_timeout_sid(gpointer param)
 	gems_reset_teacher_profile_request_counter();
 }
 
+/**
+ * gems_increase_teacher_profile_request_counter:
+ *
+ * Increase the profile request counter with one.
+ *
+ * Returns: void
+ */
 void gems_increase_teacher_profile_request_counter()
 {
 	gems_get_data()->teacher_profile_requests++;
 }
 
+/**
+ * gems_reset_teacher_profile_request_counter:
+ *
+ * Reset the profile request counter.
+ *
+ * Returns: void
+ */
 void gems_reset_teacher_profile_request_counter()
 {
 	gems_get_data()->teacher_profile_requests = 0;
 }
 
+/**
+ * gems_get_teacher_profile_request_count:
+ *
+ * Get the amount of profile requests sent
+ *
+ * Returns: the amount of profile requests
+ */
 guint gems_get_teacher_profile_request_count()
 {
 	return gems_get_data()->teacher_profile_requests;
 }
 
+/**
+ * gems_set_login_username:
+ * @username: New login username, duplicate is created
+ * @forced: TRUE when username set by teacher, FALSE if set by user
+ *
+ * Set the @username to be used for login. First clears the old username if it
+ * was set and then creates a duplicate from the given @username.
+ *
+ * Returns: void
+ */
 void gems_set_login_username(const gchar* username, gboolean forced)
 {
+	gems_clear_login_username();
 	gems_get_data()->username_to_login = g_strdup(username);
 	gems_get_data()->username_forced = forced;
 }
 
+/**
+ * gems_get_login_username:
+ *
+ * Get the username set for login
+ *
+ * Returns: the username as #gchar
+ */
 gchar* gems_get_login_username()
 {
 	return gems_get_data()->username_to_login;
 }
 
+/**
+ * gems_clear_login_username:
+ *
+ * Erase the login username if it was set.
+ *
+ * Returns: void
+ */
 void gems_clear_login_username()
 {
 	if(gems_get_data()->username_to_login)
@@ -219,11 +426,25 @@ void gems_clear_login_username()
 	}
 }
 
+/**
+ * gems_login_username_forced:
+ *
+ * Check if the login username was forced.
+ *
+ * Returns: TRUE when forced, FALSE otherwise.
+ */
 gboolean gems_login_username_forced()
 {
 	return gems_get_data()->username_forced;
 }
 
+/**
+ * gems_teacher_connection_is_connected:
+ *
+ * Check if the connection to teacher exists.
+ *
+ * Returns: TRUE if it exists, FALSE otherwise.
+ */
 gboolean gems_teacher_connection_is_connected()
 {
 	if(gems_get_teacher_connection() != NULL)
@@ -240,6 +461,13 @@ gboolean gems_teacher_connection_is_connected()
 	return FALSE;
 }
 
+/**
+ * gems_free_data:
+ *
+ * Free the #gems_components data structure.
+ *
+ * Returns: void
+ */
 void gems_free_data()
 {
 	if(gems_data)
@@ -248,13 +476,17 @@ void gems_free_data()
 		gems_data = NULL;
 	}
 }
-
-/* Initializes components of GEMS and stores them into struct gems_components
- *
- * Return: gems_components containing pointers to gems components
- */
  
-// TODO modify to support re-enabling of gems components (networking/PeerHood)
+/**
+ * jammo_gems_init:
+ * @argc: argument count
+ * @argv: array of arguments
+ *
+ * Initialize GEMS. Initializes internal structures, services, connection to
+ * PeerHood and callbacks.
+ *
+ * Returns: void
+ */
 void jammo_gems_init(int argc, char* argv[])
 {
 	gchar* logmsg = NULL;
@@ -340,7 +572,12 @@ void jammo_gems_init(int argc, char* argv[])
 	//return components;
 }
 
-/* Delete the components and free the struct
+/**
+ * jammo_gems_cleanup:
+ * 
+ * Delete the components of GEMS and free the structs. Disconnect from Peerhood
+ *
+ * Returns: void
  */
 void jammo_gems_cleanup()
 {
@@ -438,6 +675,13 @@ void jammo_gems_cleanup()
 	g_free(logmsg);
 }
 
+/**
+ * jammo_gems_cleanup_lists:
+ *
+ * Clean the initialized connections and error lists.
+ * 
+ * Returns: void
+ */
 void jammo_gems_cleanup_lists()
 {
 	gems_components* components = gems_get_data();
@@ -473,37 +717,111 @@ void gems_list_profile_parameters()
 		gems_profile_manager_get_avatar_id(NULL));
 }
 
-/*Forward the messages to collaboration module */
+/**
+ * gems_add_new_sample_to_track:
+ * @loop_id:
+ * @slot:
+ *
+ * Forward the messages to collaboration module
+ *
+ * Returns: void
+ */
 void gems_add_new_sample_to_track(guint loop_id, guint slot)
 {
 	collaboration_add_new_sample_to_track(loop_id, slot);
 }
 
+/**
+ * gems_remove_sample_from_slot:
+ * @slot:
+ *
+ * Forward the messages to collaboration module
+ *
+ * Returns: void
+ */
 void gems_remove_sample_from_slot(guint slot)
 {
 	collaboration_remove_sample_from_slot(slot);
 }
+
+/**
+ * gems_loop_sync:
+ * @list:
+ *
+ * Synchronize loop list? Forward the messages to collaboration module.
+ *
+ * Returns: void
+ */
 void gems_loop_sync(GList * list)
 {
 	collaboration_loop_sync(list);
 }
+
+/**
+ * gems_midi_events_to_track:
+ * @operation:
+ * @instrument_id:
+ * @list:
+ *
+ * Forward the messages to collaboration module
+ *
+ * Returns: void
+ */
 void gems_midi_events_to_track(GemsEventListOperation operation, gint16 instrument_id, GList * list)
 {
 	collaboration_midi_events_to_track(operation, instrument_id, list);
 }
+
+/**
+ * gems_slider_events_to_track:
+ * @operation:
+ * @instrument_id:
+ * @list:
+ *
+ * Forward the messages to collaboration module
+ */
 void gems_slider_events_to_track(GemsEventListOperation operation, gint16 instrument_id, GList * list) {
 	collaboration_slider_events_to_track(operation, instrument_id, list);
 }
+
+/**
+ * gems_start_pair_game:
+ * @theme: theme id to be used in the game
+ * @variation:
+ *
+ * Start pair game. Forward the messages to collaboration module.
+ *
+ * Returns: void
+ */
 void gems_start_pair_game(gint16 theme, gint16 variation)
 {
 		gems_components* data = gems_get_data();
 		collaboration_start_pair_game(1, 1, data);
 }
+
+/**
+ * gems_create_game_server:
+ * @port:
+ *
+ * Unused. Does nothing.
+ *
+ * Returns: 0
+ */
 int gems_create_game_server(int port)
 {
 	return 0;
 	//return collaboration_create_game_server(port);
 }
+
+/**
+ * gems_create_game_client:
+ * @address:
+ * @port:
+ *
+ * Unused. Does nothing.
+ *
+ * Returns: 0
+ */
 int gems_create_game_client(char *address, int port)
 {
 	return 0;
@@ -511,7 +829,16 @@ int gems_create_game_client(char *address, int port)
 }
 
 
-// List other JamMos which we have connected to
+/**
+ * gems_list_jammo_connections:
+ *
+ * List other JamMos which this device is connected to. Returns a COPY of the
+ * internal list with same data. Data is not copied, only the pointers. The
+ * list must be free'd by the caller but the data MUST be left intact.
+ *
+ * Returns: a pointer to #GList containing pointers to #gems_connection structs
+ * or NULL if the data cannot be accessed or the list is empty.
+ */
 GList* gems_list_jammo_connections()
 {
 	gems_components* data = gems_get_data();
@@ -525,7 +852,15 @@ GList* gems_list_jammo_connections()
 	}
 }
 
-// Get a connection with selected user id
+/**
+ * gems_get_connection_with_user_id:
+ * @userid: User id to be used for searching
+ * 
+ * Get a connection with selected @userid, returns the #gems_connection struct
+ * if found or NULL otherwise.
+ *
+ * Returns: a pointer to the connection structure or NULL if not found.
+ */
 gems_connection* gems_get_connection_with_user_id(guint32 userid)
 {
 	gems_components* data = gems_get_data();
@@ -537,7 +872,14 @@ gems_connection* gems_get_connection_with_user_id(guint32 userid)
 	return gems_communication_get_connection_with_userid(data->communication->connections,userid);
 }
 
-// Get pointer to profile of an connection element
+/**
+ * gems_get_profile:
+ * @element: Connection element to use
+ *
+ * Get pointer to profile from the given connection @element.
+ *
+ * Returns: a pointer to #gems_peer_profile or NULL if profile is not retrieved
+ */
 gems_peer_profile* gems_get_profile(gems_connection* element)
 {
 	if(element == NULL) return NULL;
@@ -545,7 +887,16 @@ gems_peer_profile* gems_get_profile(gems_connection* element)
 }
 
 /**
- * Notify callback - called by C_Callback when notify event occurs 
+ * gems_ph_callback_notify:
+ * @aEvent: Event id
+ * @aAddress: Address of the device causing the event
+ * @aData: User data
+ *
+ * Notify callback - called by C_Callback when notify event occurs. Used only 
+ * by the Peerhood library callback. Is registered into the C_Callback as
+ * function pointer.
+ * 
+ * Returns: void.
  */
 void gems_ph_callback_notify(short aEvent, const char* aAddress,void* aData)
 {
@@ -556,7 +907,25 @@ void gems_ph_callback_notify(short aEvent, const char* aAddress,void* aData)
 
 
 /**
- * New connection callback - called by C_Callback when new connection is established
+ * gems_ph_callback_newconnection:
+ * @aPort: Port which was connected
+ * @aConnection: New connection object
+ * @aConnectionId: Id of the connection
+ * @aData: User data
+ *
+ * New connection callback - called by C_Callback when new connection is 
+ * established. Used only by the Peerhood library callback. Is registered into
+ * the C_Callback as function pointer. Checks if the connection is established
+ * into correct port (correct service), only "JamMo" and "Mentor" services 
+ * accept new connections, additionally the "Collaboration" service accepts a
+ * new connection if there is an connection between the devices and the users
+ * are in the same group. Only one "basic" connection between device pairs are
+ * allowed, otherwise the created connection is disconnected. If the device 
+ * checksum is found from error lists as rejected connection it will not be
+ * accepted. New accepted connections are set into %JAMMO_CONNECTING
+ * #jammo_state and moved into initialized connections list.
+ *
+ * Returns: void
  */
 
 void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnection* aConnection, int aConnectionId, void* aData)
@@ -923,6 +1292,18 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 	//ph_c_connection_delete(aConnection);
 }
 
+/**
+ * gems_process_connections:
+ *
+ * Process the initialized connections created by other devices. Check if there
+ * is data awaiting and read it. Pass connections to "JamMo" service which have
+ * sent correct data, process error messages and disconnect connections which
+ * have invalid data. A timeout function executed periodically by Glib main
+ * loop.
+ *
+ * Returns: Integer value 0 (FALSE) or 1 (TRUE), 0 when errors or the function
+ * is required to be removed from Glib main loop.
+ */
 gint gems_process_connections()
 {	
 	gems_components* data = gems_get_data();
@@ -1061,7 +1442,15 @@ gint gems_process_connections()
 	//logmsg = g_strdup_printf("Done processing connections");
 }
 
-// For testing, shows contents of connection lists if enter is pressed
+/**
+ * gems_connection_debugging:
+ *
+ * For testing, shows contents of connection lists if enter is pressed.
+ *
+ * Returns: void
+ *
+ * Deprecated: Only for debugging.
+ */
 void gems_connection_debugging()
 {
 	gems_components* data = gems_get_data();
@@ -1163,36 +1552,111 @@ void gems_connection_debugging()
 }
 
 
-
+/**
+ * gems_set_callback_add_loop:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_add_loop_to_slot callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_add_loop(void (*func_ptr)(GObject * game, guint user_id, guint id, guint slot) ) {
 	chum_callback_add_loop_to_slot=func_ptr;
 }
 
+/**
+ * gems_set_callback_remove_loop:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_remove_loop_to_slot callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_remove_loop(void (*func_ptr)(GObject * game, guint user_id, guint slot) ) {
 	chum_callback_remove_loop_from_slot=func_ptr;
 }
 
+/**
+ * gems_set_callback_loop_sync:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_loop_sync callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_loop_sync(void (*func_ptr)(GObject * game, guint user_id, GList * list) ) {
 	chum_callback_loop_sync=func_ptr;
 }
 
+/**
+ * gems_set_callback_midi_list:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_midi_list callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_midi_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) ) {
 	chum_callback_midi_list=func_ptr;
 }
 
+/**
+ * gems_set_callback_slider_event_list:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_slider_event_list callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_slider_event_list(void (*func_ptr)(GObject * game, guint user_id, gint16 instrument_id, GemsEventListOperation operation, GList * list) ) {
 	chum_callback_slider_event_list=func_ptr;
 }
+
+/**
+ * gems_set_callback_group_control:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_group_control callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_group_control(void (*func_ptr)(gint type) ) {
 	chum_callback_group_control=func_ptr;
 }
+
+/**
+ * gems_set_callback_game:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_game callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_game(void (*func_ptr)(GObject * game, gint type, const gchar* song_info) ) {
 	chum_callback_game=func_ptr;
 }
+
+/**
+ * gems_set_callback_game_starter:
+ * @func_ptr: New function pointer to set
+ *
+ * Set #chum_callback_game_starter callback function.
+ *
+ * Returns: void
+ */
 void gems_set_callback_game_starter(void (*func_ptr)(gpointer data, gint16 track_id) ) {
 	chum_callback_game_starter=func_ptr;
 }
 
+/**
+ * gems_debugging_show_jammos:
+ *
+ * Debugging. Show all connections, print them into stdout.
+ *
+ * Returns: void
+ *
+ * Deprecated: Debugging only.
+ */
 void gems_debugging_show_jammos()
 {
 	// get COPY of a list
@@ -1215,7 +1679,14 @@ void gems_debugging_show_jammos()
 	else printf("No connected JamMos\n");
 }
 
-// Initialize PeerHood callback
+/**
+ * gems_init_peerhood_callback:
+ *
+ * Initialize PeerHood callback, set callback function pointers and create new
+ * callback.
+ *
+ * Returns: void
+ */
 void gems_init_peerhood_callback()
 {
 	void (*notify)(short, const char*,void*) = NULL;
@@ -1231,10 +1702,14 @@ void gems_init_peerhood_callback()
 	g_free(logmsg);
 }
 
-/* Enable network timeout functions
- * 
- * Add all timeout functions related to networked components inside this function.
- * This will be called if connection to PeerHood is lost and it is found again.
+/**
+ * gems_enable_network_timeout_functions:
+ *
+ * Enable network timeout functions. All timeout functions related to networked
+ * components are inside this function. This will be called if connection to 
+ * PeerHood is lost and it is found again.
+ *
+ * Return: void
  */
 void gems_enable_network_timeout_functions()
 {
@@ -1250,6 +1725,14 @@ void gems_enable_network_timeout_functions()
 	//gems_get_data()->timeout_functions[9] = g_timeout_add_full(G_PRIORITY_HIGH,1000,(GSourceFunc)gems_communication_search_teacher, NULL, NULL);
 }
 
+/**
+ * gems_register_services:
+ *
+ * Register all services into PeerHood. Set them enabled if registration is
+ * successful.
+ *
+ * Return: void
+ */
 void gems_register_services()
 {
 	gems_components* components = gems_get_data();
