@@ -20,11 +20,11 @@
 // Login
 gboolean gems_profile_manager_login(guint32 userId, gchar* username, gchar* passworddata);
 
-gint gems_profile_manager_authenticate_default_user(const gchar* passworddata);
+GemsLoginAction gems_profile_manager_authenticate_default_user(const gchar* passworddata);
 
-gint gems_profile_manager_authenticate_user(const gchar* username, const gchar* passworddata);
+GemsLoginAction gems_profile_manager_authenticate_user(const gchar* username, const gchar* passworddata);
 
-gint gems_profile_manager_set_user(const gchar* username);
+GemsChangeUserAction gems_profile_manager_set_user(const gchar* username);
 
 gboolean gems_profile_manager_change_password(const gchar* passworddata);
 
@@ -128,7 +128,7 @@ gboolean gems_profile_manager_is_authenticated();
  *
  * Returns: username
  */
-gchar* gems_profile_manager_get_loaded_username();
+const gchar* gems_profile_manager_get_loaded_username();
 
 /* Returns the profile type (PROF_TYPE_LOCAL or PROF_TYPE_REMOTE)
  * 
