@@ -12,6 +12,18 @@
 #include "gems_security.h"
 #include "../cem/cem.h"
 
+/**
+ * gems_security_create_envelope:
+ * @type: Type of the envelope
+ * @element: Connection where the envelope will be sent to
+ * @original: Original message
+ *
+ * Creates new #gems_message used for storing the envelope information.
+ * Original message content is hashed and the content is added to the end of
+ * the envelope (encryption not yet applied).
+ *
+ * Returns: new envelope as #gems_message
+ */
 gems_message* gems_security_create_envelope(guint16 type,gems_connection* element, gems_message* original)
 {
 	if(!element || !original) return NULL;
@@ -42,7 +54,18 @@ gems_message* gems_security_create_envelope(guint16 type,gems_connection* elemen
 	return envelope;
 }
 
-gint gems_security_extract_envelope(gems_connection* element)
+/**
+ * gems_security_extract_envelope
+ * @element: Connection element which contains the full envelope message in its
+ * network buffer
+ *
+ * Extract the protocol packet from the envelope. Check that the hashed content
+ * matches the hash in the envelope. The message is copied from the network 
+ * buffer back into the network buffer of the given @element.
+ *
+ * Returns: Result of the extraction as value of #GemsEnvelopeCheck
+ */
+GemsEnvelopeCheck gems_security_extract_envelope(gems_connection* element)
 {
 	gint rval = SECURITY_OK;
 	
@@ -56,8 +79,7 @@ gint gems_security_extract_envelope(gems_connection* element)
 	g_memmove(&element->nwbuffer[0],
 		&element->nwbuffer[sizeof(guint16) + sizeof(guint32) + JAMMO_MESSAGE_DIGEST_SIZE + 1],
 		(length - sizeof(guint16) - sizeof(guint32) - JAMMO_MESSAGE_DIGEST_SIZE - 1));
-		
-	// TODO compare hashes
+
 	guchar* calchash = SHA1((const guchar*)(&(element->nwbuffer)),g_ntohl(gems_connection_get_32(element,sizeof(guint16))),NULL);
 	if(!gems_security_verify_hash(storedhash,calchash,JAMMO_MESSAGE_DIGEST_SIZE))
 	{
@@ -70,6 +92,19 @@ gint gems_security_extract_envelope(gems_connection* element)
 	return rval;
 }
 
+/**
+ * gems_security_init_security:
+ * @password: Salted password created with gems_security_create_password()
+ * @salt: Salt used for password and also for security contexts
+ *
+ * Initialize the OPENSSL security components. Encryption and decryption
+ * contexts are initialized using the salted @password and the @salt using
+ * the gems_security_init_aes() function, hash is initialized with 
+ * gems_security_init_sha().
+ *
+ * Returns: TRUE when all is initialized, FALSE otherwise (or when either of
+ * the input parameters is NULL).
+ */
 gboolean gems_security_init_security(const guchar* password, const guchar* salt)
 {
 	cem_add_to_log("Security contexts initialization.", J_LOG_DEBUG);
@@ -114,6 +149,17 @@ gboolean gems_security_init_security(const guchar* password, const guchar* salt)
 	return TRUE;
 }
 
+/**
+ * gems_security_change_password:
+ * @password: new, salted password
+ * @salt: new salt
+ *
+ * Initialize the security with new @password and @salt. Clears the existing
+ * security contexts and calls gems_security_init_security().
+ *
+ * Returns: TRUE when all is initialized, FALSE otherwise (or when either of
+ * the input parameters is NULL).
+ */
 gboolean gems_security_change_password(const guchar* password, const guchar* salt)
 {
 	gems_security_clear_security();
@@ -130,6 +176,18 @@ gboolean gems_security_change_password(const guchar* password, const guchar* sal
 	}
 }
 
+/**
+ * gems_security_create_password:
+ * @password_data: New plain password to be used for creating the salted
+ * password
+ * @salt: salt to be used with password
+ *
+ * Concatenates the salt into the end of the password to make rainbow table
+ * attacks to be not so effective. Password must not exceed the %PASSLEN - 
+ * %AES_SALT_LENGTH (56 bytes).
+ *
+ * Returns: new salted password
+ */
 guchar* gems_security_create_password(const gchar* password_data, const guchar* salt)
 {
 	guchar* passwd = NULL;
@@ -144,6 +202,14 @@ guchar* gems_security_create_password(const gchar* password_data, const guchar*
 	return passwd;
 }
 
+/**
+ * gems_security_clear_security:
+ *
+ * Clear all OPENSSL security contexts. Frees the #gems_security_context
+ * structure.
+ *
+ * Returns: void
+ */
 void gems_security_clear_security()
 {
 	gchar* logmsg = NULL;
@@ -196,6 +262,14 @@ void gems_security_clear_security()
 	cem_add_to_log("Security contexts cleanup.", J_LOG_DEBUG);
 }
 
+/**
+ * gems_security_create_password_salt:
+ *
+ * Create new random salt for password. Salt is %AES_SALT_LENGTH long and is
+ * created from two random 32bit integers.
+ *
+ * Returns: new random salt.
+ */
 guchar* gems_security_create_password_salt()
 {
 	guchar* salt = g_new0(guchar,sizeof(guchar) * AES_SALT_LENGTH);
@@ -210,7 +284,20 @@ guchar* gems_security_create_password_salt()
 	return salt;
 }
 
-// encryption context, decryption context, key/passwd data, key data length, salt
+/**
+ * gems_security_init_aes:
+ * @enc: Allocated encryption EVP context
+ * @dec: Allocated decryption EVP context
+ * @salt: Salt to use in context initializations
+ * @keydata: Salted password data
+ * @keylength: Length of the salted password data
+ *
+ * Initialize en- and decryption contexts using AES 256 with CBC. SHA256 is
+ * used as cryptographic hash. 
+ *
+ * Returns: TRUE when both encryption and decryption contexts are initialized,
+ * FALSE otherwise.
+ */
 gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, const guchar* salt, const guchar* keydata, guint keylength)
 {
 	guchar key[32], iv[32];
@@ -254,6 +341,14 @@ gboolean gems_security_init_aes(EVP_CIPHER_CTX* enc, EVP_CIPHER_CTX* dec, const
 	return returnvalue;
 }
 
+/**
+ * gems_security_init_sha:
+ * @md: Allocated EVP message digest context
+ *
+ * Initialize cryptographic hashing (SHA256).
+ * 
+ * Returns: TRUE when success, FALSE otherwise.
+ */
 gboolean gems_security_init_sha(EVP_MD_CTX* md)
 {
 	//EVP_MD_CTX_init(md); Not needed since md is created with EVP_MD_CTX_Create
@@ -268,6 +363,15 @@ gboolean gems_security_init_sha(EVP_MD_CTX* md)
 	return TRUE;
 }
 
+/**
+ * gems_security_calculate_hash:
+ * @data: Data where hash is to be calculated
+ * @data_length: Length of the data, length of the hash result is set into this
+ *
+ * Calculate hash from given data using SHA256 context.
+ *
+ * Returns: calculated hash, length is stored into @data_length.
+ */
 guchar* gems_security_calculate_hash(const guchar* data, guint* data_length)
 {
 	guint hash_length = 0;
@@ -322,6 +426,17 @@ guchar* gems_security_calculate_hash(const guchar* data, guint* data_length)
 	return hash;
 }
 
+/**
+ * gems_security_verify_hash:
+ * @hash1: First hash
+ * @hash2: Second hash
+ * @hashlength: Length of the hashes @hash1 and @hash2 (both must be equal in 
+ * length)
+ *
+ * Compare the hashes @hash1 and @hash2. Return TRUE if they are identical.
+ *
+ * Returns: TRUE when hashes are identical, FALSE otherwise.
+ */
 gboolean gems_security_verify_hash(const guchar* hash1, const guchar* hash2, guint32 hashlength)
 {
 	if(hash1 == NULL || hash2 == NULL) return FALSE;
@@ -330,7 +445,16 @@ gboolean gems_security_verify_hash(const guchar* hash1, const guchar* hash2, gui
 	return TRUE;
 }
 
-// encryption context, data to encrypt, data length
+/**
+ * gems_security_encrypt_data:
+ * @profile_data: Serialized profile data to enrcypt
+ * @data_length: The length of the serialized profile data
+ *
+ * Encrypt the given serialized @profile_data using the initialized security
+ * contexts and private password.
+ *
+ * Returns: Encrypted profile or NULL in case or errors.
+ */
 guchar* gems_security_encrypt_data(const guchar* profile_data, guint* data_length)
 {
 	EVP_CIPHER_CTX* enc = NULL;
@@ -378,7 +502,16 @@ guchar* gems_security_encrypt_data(const guchar* profile_data, guint* data_lengt
 	return encrypted_profile;
 }
 
-// decryption context, data to decrypt, data length
+/**
+ * gems_security_encrypt_data:
+ * @profile_data: Encrypted profile data to dercypt
+ * @data_length: The length of the encrypted profile data
+ *
+ * Decrypt the given encrypted @profile_data using the initialized security
+ * contexts and private password.
+ *
+ * Returns: Decrypted profile in serialized form or NULL in case or errors.
+ */
 guchar* gems_security_decrypt_data(const guchar* profile_data, guint* data_length)
 {
 	EVP_CIPHER_CTX* dec = NULL;
